# Ziplit.Tuser
## Free quik user bases for your projects

Tuser allows you to create databases for users of your project.

## Features
* Quick start. You don't need to design a database for a long time - just one command will save you from torment.
* Safety. The data is completely secured by an encryption system and access level differentiation.
* Comfortable. All in one package without unnecessary things.
* Completely free of charge. Although I will not refuse donations :0

[//]: # (## Setup)

[//]: # (After adding the Tuser package to your project, you need to create a skeleton base for your project. You can do it like this:)

[//]: # (```)

[//]: # (    python tuser.py quick)

[//]: # (```)